//
// Shige-Fuji Project
// SwiftUI Archives
//
// Copyright (c) Watanabe-Denki, Inc.
//   https://wdkk.co.jp/
//
// This software is released under the MIT License.
//   https://opensource.org/licenses/mit-license.php
//

import UIKit
import RealityKit

class CustomARView: ARView {
    // サーフェスシェーダ名
    let surfaceShaderName: String = "textureSurfaceShader"
    
    // アンカー
    var firstAnchor: AnchorEntity = AnchorEntity()
 
    required init(frame frameRect: CGRect) {
        super.init(frame: frameRect)
        createScene()
    }
    
    @MainActor required dynamic init?(coder decoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func prepareAnchor() {
        // 検出無しに設置するアンカー
        firstAnchor.position = simd_make_float3(0.0, -0.5, -1.0) // アンカーの位置は、デバイス初期位置から0.5m下、1m奥（ARKitでは1m = 1.0）
        self.scene.anchors.append(firstAnchor)   // CustomARView(self)にアンカーを追加
    }
    
    func createScene() {
        // アンカーの準備
        prepareAnchor()
        
        // 球体を作成
        let sphere_custom = ModelEntity(mesh: .generateSphere(radius: 0.2))
        
        // マテリアルを作る
        var materials:[SimpleMaterial] = .init(repeating: SimpleMaterial(), count:1 )
        // テクスチャを作成
        let texture = try! MaterialParameters.Texture( .load( named:"LilyIcon" ) )
        // マテリアルカラーをテクスチャで作成
        let base_color = SimpleMaterial.BaseColor( tint:.white, texture:texture )
        // materials1つのcolorにbase_colorを設定
        materials[0].color = base_color
        
        sphere_custom.model?.materials = materials
        sphere_custom.transform = Transform(translation: simd_make_float3(0.0, 0.4, 0.0))
        self.firstAnchor.addChild(sphere_custom)    // アンカーに追加
    }
}

